@@ -275,8 +275,9 @@ class DashboardSession(object):
         return project
 
 
-    def get_project(self, project_name, get_neighbors=True):
-        """Returns a [Project][ccrenew.dashboard.project.Project] object given a project name.
+    def get_project(self, project_name: str, get_neighbors: bool=True) -> Project:
+        """
+        Return a [Project][ccrenew.dashboard.project.Project] object given a project name.
 
         Args:
             project_name (str or Project): Name of a [Project][ccrenew.dashboard.project.Project] to return from the
@@ -285,7 +286,7 @@ class DashboardSession(object):
             get_neighbors (bool, optional): Flag to add & initialize neighbor [Projects][ccrenew.dashboard.project.Project].
 
         Returns:
-            Project: the [Project][ccrenew.dashboard.project.Project] for the given the project name.
+            Project object for the given the project name.
                 If the project does not exist in the session when the call is made, the project will be initialized & returned.
         """
         if isinstance(project_name, Project):
@@ -299,18 +300,26 @@ class DashboardSession(object):
         return project
 
 
-    def process_project(self, project_name, reprocess=False):
-        """Processes data for the given [Project][ccrenew.dashboard.project.Project].
+    def process_project(self, project_name: str, reprocess: bool=False) -> Project:
+        """
+        Process data for the given [Project][ccrenew.dashboard.project.Project].
 
         Args:
             project_name (str or Project): The name of the [Project][ccrenew.dashboard.project.Project] to process.
-            reprocess (bool, optional): Whether to reprocess the data. This option will likely
+            reprocess (bool): Whether to reprocess the data. This option will likely
                 be uncommon as any changes to a [Project's][ccrenew.dashboard.project.Project] config file or powertrack file will
                 automatically reprocess that data. This could be used if any changes are made
                 outside of the config/powertrack file or a change is made to a neighbor.
+        Returns:
+            Processed Project object.
         """
         if isinstance(project_name, list):
-            self.process_projects(project_name, reprocess=reprocess)
+            # Pass function arguments to `process_projects()`.
+            # Argument 0 is `self` so we'll pass arguments 1 and on
+            func_args = list(locals().values())[1:]
+            project = self.process_projects(*func_args)
+
+            return project
         elif isinstance(project_name, (str, unicode, Project)):
             start = time.time()
             print(f'Processing {project_name}....')
@@ -321,7 +330,7 @@ class DashboardSession(object):
             try:
                 last_update_config_file = os.path.getmtime(project.config_filepath)
                 last_update_powertrack_file = os.path.getmtime(project.powertrack_filepath)
-            except FileNotFoundError:
+            except:
                 self.__update_project_filepaths()
                 last_update_config_file = os.path.getmtime(project.config_filepath)
                 last_update_powertrack_file = os.path.getmtime(project.powertrack_filepath)
@@ -370,19 +379,33 @@ class DashboardSession(object):
         [Project][ccrenew.dashboard.project.Project] in a list.
 
         Args:
-            project_list (list): List of project names of [Project][ccrenew.dashboard.project.Project] objects to process.
+            project_list (list): List of [Project][ccrenew.dashboard.project.Project] names process.
             reprocess (bool, optional): See [process_project()][ccrenew.dashboard.session.DashboardSession.process_project].
         """
+        # Store function arguments in case we need to pass them to `process_project()`.
+        # Argument 0 is `self` so we'll pass arguments 1 and on
+        func_args = list(locals().values())[1:]
+
         if isinstance(project_list, (str, unicode, Project)):
-            project_name = project_list
-            project = self.process_project(project_name, reprocess=reprocess)
+            project = self.process_project(*func_args)
+
             return project
         elif isinstance(project_list, list):
-            for i, project_name in enumerate(project_list):
-                print('*******************************************************')
-                print(f'Processing {project_name} - Project {i+1} of {len(project_list)}.')
-                print('*******************************************************')
-                self.process_project(project_name, reprocess=reprocess)
+            # If a list was passed, argument 0 is the project list
+            # So we'll pass arguments 1 and on
+            func_args = func_args[1:]
+
+            if len(project_list) == 1:
+                project_name = project_list[0]
+                project = self.process_project(project_name, *func_args)
+
+                return project
+            else:
+                for i, project_name in enumerate(project_list):
+                    print('*******************************************************')
+                    print(f'Processing {project_name} - Project {i+1} of {len(project_list)}.')
+                    print('*******************************************************')
+                    self.process_project(project_name, *func_args)
         else:
             raise TypeError("`project_list` must be a string or Python list! Please reformat input and try again.")
     
@@ -396,6 +419,78 @@ class DashboardSession(object):
         self.process_projects(project_list)
 
 
+    def export_project(self, project_name: str, server: str='dev', save_pickle: bool=True, *args) -> None:
+        """
+        Export project to desired location(s).
+
+        Args:
+            project_name (str or Project): Name of a project to export.
+            server (str): SQL table to export to. Options are `prod` or `dev`.
+            save_pickle (bool): Option to save pickle after exporting.
+        
+        Optional Args:
+            These allow the user to export only certain parts of the project.
+            
+            <b>Options:</b>
+            <br>
+                <code>'excel'</code>: Exports dataframes to Excel dashboard template.
+            <br>
+                <code>'df'</code>: Export dataframe to the `Dataframes` folder of the project's
+                [project_directory][ccrenew.dashboard.project.Project.project_directory],
+                S3, and Bartertown PostgreSQL database.
+            <br>
+                <code>'summary'</code>: Exports monthly summary data to S3 and
+                Bartertown PostgreSQL database.
+            <br>
+                <code>'snow'</code>: Exports [snow_data][ccrenew.dashboard.project.Project.snow_data] and
+                [snow_coverage][ccrenew.dashboard.project.Project.snow_coverage] dataframes to S3.
+        """
+        if isinstance(project_name, list):
+            # Pass function arguments to `export_projects()`.
+            # Argument 0 is `self` so we'll pass arguments 1 and on
+            func_args = list(locals().values())[1:]
+            project = self.export_projects(func_args)
+        elif isinstance(project_name, (str, Project)):
+            project = self.process_project(project_name)
+            project.export(server, save_pickle, *args)
+            print(f"{project.project_name} successfully exported.")
+        else:
+            raise TypeError("`project_name` must be a string or Project object! Please reformat input and try again.")
+
+    
+    def export_projects(self, project_list: str, server: str='dev', save_pickle: bool=True, *args) -> None:
+        """Calls [export_project()][ccrenew.dashboard.session.DashboardSession.export_project] for each
+        [Project][ccrenew.dashboard.project.Project] in a list.
+
+        Args:
+            project_list (list): List of [Project][ccrenew.dashboard.project.Project] names process.
+            server (str): See [export_project()][ccrenew.dashboard.session.DashboardSession.export_project].
+            save_pickle (bool): See [export_project()][ccrenew.dashboard.session.DashboardSession.export_project].
+        
+        Optional Args:
+            See [export_project()][ccrenew.dashboard.session.DashboardSession.export_project].
+        """
+        # Store function arguments in case we need to pass them to `export_project()`.
+        # Argument 0 is `self` so we'll pass arguments 1 and on
+        func_args = list(locals().values())[1:]
+
+        if isinstance(project_list, (str, unicode, Project)):
+            project = self.export_project(*func_args)
+        elif isinstance(project_list, list):
+            # If a list was passed, argument 0 is the project list
+            # So we'll pass arguments 1 and on
+            func_args = func_args[1:]
+
+            if len(project_list) == 1:
+                project_name = project_list[0]
+                self.export_project(project_name, *func_args)
+            else:
+                for project_name in project_list:
+                    self.export_project(project_name, *func_args)
+        else:
+            raise TypeError("`project_list` must be a string or Python list! Please reformat input and try again.")
+
+
     def remove_project(self, project_name:str) -> None:
         """Remove the selected project from the active session.
 
